@@ -1,7 +1,7 @@
 # #' Get Cognito config from .yml
 # #'
 # #' Return all required configuration from file .yml to connect with Amazon Cognito instance.
-#' @import config
+#' @importFrom config get
 # #' @return list|FALSE
 # #' @author Pablo Pagnone
 get_config <- function() {
@@ -9,7 +9,19 @@ get_config <- function() {
   # Get configuration for Cognito Service.
   tryCatch({
     result <- config::get()$cognito
-    config_names <- names(unlist(result))
+
+    validate_config(result)
+
+    result
+  },
+  error = function(e) {
+    return(FALSE)
+  })
+
+}
+
+validate_config <- function(config) {
+    config_names <- names(unlist(config))
     required_names <- c("group_name",
                         "group_id",
                         "oauth_flow",
@@ -20,14 +32,8 @@ get_config <- function() {
                         "app_client_secret")
 
     missing_args <- setdiff(required_names, config_names)
-
-    if(length(missing_args) > 0 || isFALSE(result$oauth_flow %in% c("code", "token"))) {
+    if(length(missing_args) > 0 || isFALSE(config$oauth_flow %in% c("code", "token"))) {
       stop("Missing params in config")
     }
-    result
-  },
-  error = function(e) {
-    return(FALSE)
-  })
-
+    return(TRUE)
 }
